@@ -23,7 +23,7 @@ use integer; # vroom!
 use strict;
 use Carp ();
 use vars qw($VERSION );
-$VERSION = '3.12';
+$VERSION = '3.17';
 #use constant DEBUG => 7;
 BEGIN {
   require Pod::Simple;
@@ -88,8 +88,8 @@ sub parse_lines {             # Usage: $parser->parse_lines(@lines)
       DEBUG > 2 and print "First line: [$source_line]\n";
 
       if( ($line = $source_line) =~ s/^\xEF\xBB\xBF//s ) {
-        DEBUG and print "UTF-8 BOM seen.  Faking a '=encode utf8'.\n";
-        $self->_handle_encoding_line( "=encode utf8" );
+        DEBUG and print "UTF-8 BOM seen.  Faking a '=encoding utf8'.\n";
+        $self->_handle_encoding_line( "=encoding utf8" );
         $line =~ tr/\n\r//d;
         
       } elsif( $line =~ s/^\xFE\xFF//s ) {
@@ -519,7 +519,7 @@ sub _ponder_paragraph_buffer {
     #   don't require any lookahead, but all others (bullets
     #   and numbers) do.
 
-# TODO: winge about many kinds of directives in non-resolving =for regions?
+# TODO: whinge about many kinds of directives in non-resolving =for regions?
 # TODO: many?  like what?  =head1 etc?
 
     $para = shift @$paras;
@@ -1383,7 +1383,7 @@ sub _ponder_Verbatim {
   for(my $i = 2; $i < @$para; $i++) {
     foreach my $line ($para->[$i]) { # just for aliasing
       # Strip indentation.
-      $line =~ s/^\E$indent// if $indent
+      $line =~ s/^\Q$indent// if $indent
           && !($self->{accept_codes} && $self->{accept_codes}{VerbatimFormatted});
       while( $line =~
         # Sort of adapted from Text::Tabs -- yes, it's hardwired in that
@@ -1701,30 +1701,15 @@ sub _treelet_from_formatting_codes {
     if(defined $1) {
       if(defined $2) {
         DEBUG > 3 and print "Found complex start-text code \"$1\"\n";
-        # signal that we're looking for simple unless we're in complex.
-        if ($stack[-1]) {
-            # We're in complex already. It's just stuff.
-            DEBUG > 4 and print " It's just stuff.\n";
-            push @{ $lineage[-1] }, $1;
-        } else {
-            # length of the necessary complex end-code string
-            push @stack, length($2) + 1;
-            push @lineage, [ substr($1,0,1), {}, ];  # new node object
-            push @{ $lineage[-2] }, $lineage[-1];
-        }
+        push @stack, length($2) + 1; 
+          # length of the necessary complex end-code string
       } else {
         DEBUG > 3 and print "Found simple start-text code \"$1\"\n";
-        if ($stack[-1]) {
-            # We're in complex already. It's just stuff.
-            DEBUG > 4 and print " It's just stuff.\n";
-            push @{ $lineage[-1] }, $1;
-        } else {
-            # signal that we're looking for simple.
-            push @stack, 0;
-            push @lineage, [ substr($1,0,1), {}, ];  # new node object
-            push @{ $lineage[-2] }, $lineage[-1];
-        }
+        push @stack, 0;  # signal that we're looking for simple
       }
+      push @lineage, [ substr($1,0,1), {}, ];  # new node object
+      push @{ $lineage[-2] }, $lineage[-1];
+      
     } elsif(defined $4) {
       DEBUG > 3 and print "Found apparent complex end-text code \"$3$4\"\n";
       # This is where it gets messy...
@@ -1828,7 +1813,6 @@ sub stringify_lol {  # function: stringify_lol($lol)
 
 sub _stringify_lol {  # the real recursor
   my($lol, $to) = @_;
-  use UNIVERSAL ();
   for(my $i = 2; $i < @$lol; ++$i) {
     if( ref($lol->[$i] || '') and UNIVERSAL::isa($lol->[$i], 'ARRAY') ) {
       _stringify_lol( $lol->[$i], $to);  # recurse!
@@ -1927,7 +1911,7 @@ sub pretty { # adopted from Class::Classless
 
 # A rather unsubtle method of blowing away all the state information
 # from a parser object so it can be reused. Provided as a utility for
-# backward compatibilty in Pod::Man, etc. but not recommended for
+# backward compatibility in Pod::Man, etc. but not recommended for
 # general use.
 
 sub reinit {
