@@ -5,7 +5,7 @@ use strict;
 use vars qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
  $CSS $JAVASCRIPT $SLEEPY $SEARCH_CLASS @ISA
 );
-$VERSION = '3.12';
+$VERSION = '3.17';
 @ISA = ();  # Yup, we're NOT a subclass of Pod::Simple::HTML!
 
 # TODO: nocontents stylesheets. Strike some of the color variations?
@@ -13,8 +13,6 @@ $VERSION = '3.12';
 use Pod::Simple::HTML ();
 BEGIN {*esc = \&Pod::Simple::HTML::esc }
 use File::Spec ();
-use UNIVERSAL ();
-  # "Isn't the Universe an amazing place?  I wouldn't live anywhere else!"
 
 use Pod::Simple::Search;
 $SEARCH_CLASS ||= 'Pod::Simple::Search';
@@ -728,7 +726,7 @@ sub _gen_css_wad {
       'whtgrng', # white_with_green_on_grey
       'grygrnw', # grey_with_green_on_white
   ) {
-    my $outname = "$variation\_";
+    my $outname = $variation;
     my $this_css = join "\n",
       "/* This file is autogenerated.  Do not edit.  $outname */\n",
       "\@import url(\"./_$variation.css\");",
@@ -737,7 +735,7 @@ sub _gen_css_wad {
     ;
     my $name = $outname;    
     $name =~ tr/-_/  /;
-    $self->add_css( "$outname.css", 0, $name, 0, 0, \$this_css);
+    $self->add_css( "_$outname.css", 0, $name, 0, 0, \$this_css);
   }
 
   return;
@@ -1084,7 +1082,7 @@ Example:
   % mkdir out_html
   % perl -MPod::Simple::HTMLBatch -e Pod::Simple::HTMLBatch::go @INC out_html
       (to convert the pod from Perl's @INC
-       files under the directory ../htmlversion)
+       files under the directory ./out_html)
 
 (Note that the command line there contains a literal atsign-I-N-C.  This
 is handled as a special case by batch_convert, in order to save you having
@@ -1097,7 +1095,7 @@ Example:
   % chmod og-rx ../seekrut
   % perl -MPod::Simple::HTMLBatch -e Pod::Simple::HTMLBatch::go . ../htmlversion
       (to convert the pod under the current dir into HTML
-       files under the directory ../htmlversion)
+       files under the directory ./seekrut)
 
 Example:
 
@@ -1143,7 +1141,7 @@ directory:
 
 =item $batchconv->batch_convert( 'somedir:someother:also' , ...);
 
-This specifies that you want the dirs "somedir", "somother", and "also"
+This specifies that you want the dirs "somedir", "someother", and "also"
 scanned, just as if you'd passed the arrayref
 C<[qw( somedir someother also)]>.  Note that a ":"-separator is normal
 under Unix, but Under MSWin, you'll need C<'somedir;someother;also'>
@@ -1228,7 +1226,7 @@ If you set this to a false value, no contents file will be written.
 This specifies what string should be put at the beginning of
 the contents page.
 The default is a string more or less like this:
-  
+
   <html>
   <head><title>Perl Documentation</title></head>
   <body class='contentspage'>
