@@ -1,7 +1,7 @@
 
 require 5;
 package Pod::Simple::PullParser;
-$VERSION = '3.12';
+$VERSION = '3.17';
 use Pod::Simple ();
 BEGIN {@ISA = ('Pod::Simple')}
 
@@ -205,7 +205,6 @@ sub get_token {
   return shift @{$self->{'token_buffer'}}; # that's an undef if empty
 }
 
-use UNIVERSAL ();
 sub unget_token {
   my $self = shift;
   DEBUG and print "Ungetting ", scalar(@_), " tokens: ",
@@ -454,7 +453,7 @@ sub _get_titled_section {
   $self->unget_token(@to_unget);
   
   if(DEBUG) {
-    if(defined $title) { print "  Returing title <$title>\n" }
+    if(defined $title) { print "  Returning title <$title>\n" }
     else { print "Returning title <>\n" }
   }
   
@@ -533,7 +532,7 @@ And elsewhere:
  package SomePodProcessor;
  use strict;
  use base qw(Pod::Simple::PullParser);
- 
+
  sub run {
    my $self = shift;
   Token:
@@ -624,14 +623,14 @@ process the token-stream from the beginning.
 For example, suppose you have a document that starts out:
 
   =head1 NAME
-  
+
   Hoo::Boy::Wowza -- Stuff B<wow> yeah!
 
 $parser->get_title on that document will return "Hoo::Boy::Wowza --
 Stuff wow yeah!". If the document starts with:
 
   =head1 Name
-  
+
   Hoo::Boy::W00t -- Stuff B<w00t> yeah!
 
 Then you'll need to pass the C<nocase> option in order to recognize "Name":
@@ -649,7 +648,7 @@ the title seems to be of the form "SomeModuleName -- description".
 For example, suppose you have a document that starts out:
 
   =head1 NAME
-  
+
   Hoo::Boy::Wowza -- Stuff B<wow> yeah!
 
 then $parser->get_short_title on that document will return
@@ -658,14 +657,14 @@ then $parser->get_short_title on that document will return
 But if the document starts out:
 
   =head1 NAME
-  
+
   Hooboy, stuff B<wow> yeah!
 
 then $parser->get_short_title on that document will return "Hooboy,
 stuff wow yeah!". If the document starts with:
 
   =head1 Name
-  
+
   Hoo::Boy::W00t -- Stuff B<w00t> yeah!
 
 Then you'll need to pass the C<nocase> option in order to recognize "Name":
@@ -770,6 +769,7 @@ Pod::Simple is maintained by:
 =back
 
 =cut
+
 JUNK:
 
 sub _old_get_title {  # some witchery in here
@@ -834,7 +834,7 @@ sub _old_get_title {  # some witchery in here
   $self->unget_token(@to_unget);
   
   if(DEBUG) {
-    if(defined $title) { print "  Returing title <$title>\n" }
+    if(defined $title) { print "  Returning title <$title>\n" }
     else { print "Returning title <>\n" }
   }
   
